@@ -1,8 +1,12 @@
 package SQL::Statement::Term;
 
-our $VERSION = '1.28';
+use strict;
+use warnings;
+
+our $VERSION = '1.30';
 
 use Scalar::Util qw(weaken);
+use Carp ();
 
 =pod
 
@@ -61,7 +65,11 @@ sub DESTROY
     undef $self->{OWNER};
 }
 
-sub value($) { Carp::confess( sprintf( q{pure virtual function '%s->value' called}, ref( $_[0] ) || __PACKAGE__ ) ); }
+sub value($)
+{
+    Carp::confess(
+              sprintf( q{pure virtual function '%s->value' called}, ref( $_[0] ) || __PACKAGE__ ) );
+}
 
 package SQL::Statement::ConstantTerm;
 
@@ -121,6 +129,7 @@ package SQL::Statement::ColumnValue;
 use vars qw(@ISA);
 @ISA = qw(SQL::Statement::Term);
 
+use Carp qw(croak);
 use Params::Util qw(_INSTANCE _ARRAY0 _SCALAR);
 use Scalar::Util qw(looks_like_number);
 
